==> arklex-0.0.7.tar.gz: arklex-0.0.7/benchmark/tau_bench/envs/retail/env.py <==
# Copyright Sierra

from benchmark.tau_bench.envs.base import Env
from benchmark.tau_bench.envs.retail.data import load_data
from benchmark.tau_bench.envs.retail.rules import RULES
from benchmark.tau_bench.envs.retail.tools import ALL_TOOLS
from benchmark.tau_bench.envs.retail.wiki import WIKI
from typing import Optional, Union
from benchmark.tau_bench.envs.user import UserStrategy


class MockRetailDomainEnv(Env):
    def __init__(
        self,
        user_strategy: Union[str, UserStrategy] = UserStrategy.LLM,
        user_model: str = "gpt-4o",
        user_provider: Optional[str] = None,
        task_split: str = "test",
        task_index: Optional[int] = None,
    ):
        match task_split:
            case "test":
                from benchmark.tau_bench.envs.retail.tasks_test import TASKS_TEST as tasks
            case "train":
                from benchmark.tau_bench.envs.retail.tasks_train import TASKS_TRAIN as tasks
            case "dev":
                from benchmark.tau_bench.envs.retail.tasks_dev import TASKS_DEV as tasks
            case _:
                raise ValueError(f"Unknown task split: {task_split}")
        super().__init__(
            data_load_func=load_data,
            tools=ALL_TOOLS,
            tasks=tasks,
            wiki=WIKI,
            rules=RULES,
            user_strategy=user_strategy,
            user_model=user_model,
            user_provider=user_provider,
            task_index=task_index,
        )
        self.terminate_tools = ["transfer_to_human_agents"]

==> arklex-0.0.16rc3.tar.gz: arklex-0.0.16rc3/benchmark/tau_bench/envs/retail/env.py <==
# Copyright Sierra

from benchmark.tau_bench.envs.base import Env
from benchmark.tau_bench.envs.retail.data import load_data
from benchmark.tau_bench.envs.retail.rules import RULES
from benchmark.tau_bench.envs.retail.tools import ALL_TOOLS
from benchmark.tau_bench.envs.retail.wiki import WIKI
from typing import Optional, Union
from benchmark.tau_bench.envs.user import UserStrategy


class MockRetailDomainEnv(Env):
    def __init__(
        self,
        user_strategy: Union[str, UserStrategy] = UserStrategy.LLM,
        user_model: str = "gpt-4o",
        user_provider: Optional[str] = None,
        task_split: str = "test",
        task_index: Optional[int] = None,
    ):
        match task_split:
            case "test":
                from benchmark.tau_bench.envs.retail.tasks_test import (
                    TASKS_TEST as tasks,
                )
            case "train":
                from benchmark.tau_bench.envs.retail.tasks_train import (
                    TASKS_TRAIN as tasks,
                )
            case "dev":
                from benchmark.tau_bench.envs.retail.tasks_dev import TASKS_DEV as tasks
            case _:
                raise ValueError(f"Unknown task split: {task_split}")
        super().__init__(
            data_load_func=load_data,
            tools=ALL_TOOLS,
            tasks=tasks,
            wiki=WIKI,
            rules=RULES,
            user_strategy=user_strategy,
            user_model=user_model,
            user_provider=user_provider,
            task_index=task_index,
        )
        self.terminate_tools = ["transfer_to_human_agents"]
